@@ -2,7 +2,7 @@
 
 import copy
 import logging
-from abc import ABC
+from abc import ABC, abstractmethod
 from enum import Enum
 from typing import Optional
 
@@ -17,8 +17,8 @@ class Device(Enum):
     DIMMING = "1a"
     GAS = "1b"
     AC = "1c"
-    SWITCH = "1f"
-    AWAY_MODE = "2a"
+    OUTLET = "1f"
+    AWAY = "2a"
     FAN = "2b"
     EV = "34"
     USAGE = "43"
@@ -81,7 +81,7 @@ class ImazuPacket(ABC):
     @property
     def name(self) -> str:
         """Name"""
-        return self.device.name
+        return str(self.device.name).title()
 
     @property
     def room_id(self) -> int:
@@ -113,6 +113,7 @@ class ImazuPacket(ABC):
         """Create a str of hexadecimal numbers from a ImazuPacket object."""
         return ''.join(self.packet)
 
+    @abstractmethod
     def parse_state_packets(self) -> list:
         """State packet Parse"""
         _LOGGER.warning('%s not implement set status, %s', self.name, ''.join(self.packet))
@@ -129,8 +130,8 @@ class ImazuPacket(ABC):
             packets.append(packet)
         return packets
 
-    def make_base(self, cmd: Cmd, value_type: ValueType) -> bytearray:
-        """Base packet Make"""
+    def _make_base(self, cmd: Cmd, value_type: ValueType) -> bytearray:
+        """Base packet internal Make"""
         # 01 or 1a, device, cmd, value_type, sub, change_value, state_value
         packet: bytearray = bytearray.fromhex(self.type + str(self.device.value))
         packet.append(int(str(cmd.value), 16))
@@ -138,16 +139,28 @@ class ImazuPacket(ABC):
         packet.append(int(self.sub, 16))
         return packet
 
-    def make_scan(self, value_type: ValueType) -> bytearray:
-        """Scan packet Make"""
-        packet = self.make_base(Cmd.SCAN, value_type)
+    def _make_scan(self, value_type: ValueType) -> bytearray:
+        """Scan packet Internal make"""
+        packet = self._make_base(Cmd.SCAN, value_type)
         packet.append(0)
         packet.append(0)
         return packet
 
+    @abstractmethod
+    def make_scan(self) -> bytearray:
+        """Scan packet Make"""
+        pass
 
-class GuardPacket(ImazuPacket):
-    """Imazu guard packet"""
+    def make_change(self, value_type: ValueType, change_value: int) -> bytearray:
+        """Change packet Make"""
+        packet = self._make_base(Cmd.CHANGE, value_type)
+        packet.append(change_value)
+        packet.append(0)
+        return packet
+
+
+# class GuardPacket(ImazuPacket):
+#    """Imazu guard packet"""
 
 
 class ThermostatPacket(ImazuPacket):
@@ -204,23 +217,17 @@ class ThermostatPacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_mode(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.MODE)
+        return super()._make_scan(ValueType.MODE)
 
     def make_change_mode(self, mode: Mode) -> bytearray:
         """Mode packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.MODE)
-        packet.append(int(str(mode.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.MODE, int(str(mode.value), 16))
 
     def make_change_target_temp(self, temp: int) -> bytearray:
         """Target temp packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.TEMP)
-        packet.append(temp)
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.TEMP, temp)
 
 
 class LightPacket(ImazuPacket):
@@ -265,20 +272,17 @@ class LightPacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_bool(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.BOOL)
+        return super()._make_scan(ValueType.BOOL)
 
     def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
-        packet.append(int(str(power.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(power.value), 16))
 
 
-class DimmingPacket(ImazuPacket):
-    """Imazu dimming packet"""
+# class DimmingPacket(ImazuPacket):
+#    """Imazu dimming packet"""
 
 
 class GasPacket(ImazuPacket):
@@ -309,24 +313,21 @@ class GasPacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_valve(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.VALVE)
+        return super()._make_scan(ValueType.VALVE)
 
     def make_change_valve_close(self) -> bytearray:
         """Valve close packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.VALVE)
-        packet.append(int(GasPacket.Valve.CLOSE.value, 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(GasPacket.Valve.CLOSE), 16))
 
 
-class AcPacket(ImazuPacket):
-    """Imazu ac packet"""
+# class AcPacket(ImazuPacket):
+#    """Imazu ac packet"""
 
 
-class SwitchPacket(ImazuPacket):
-    """Imazu switch packet
+class OutletPacket(ImazuPacket):
+    """Imazu outlet packet
 
     - SCAN
     > f7 0b 01 1f 01 40 10 00 00 b3 ee
@@ -344,7 +345,7 @@ class SwitchPacket(ImazuPacket):
     """
 
     class Power(Enum):
-        """Switch Power"""
+        """outlet Power"""
         ON = "01"
         OFF = "02"
 
@@ -353,7 +354,7 @@ class SwitchPacket(ImazuPacket):
         if self.value_type == ValueType.BOOL:
 
             def parse_state(state_value: list[str]):
-                return {'power': SwitchPacket.Power(state_value[0])}
+                return {'power': OutletPacket.Power(state_value[0])}
 
             if self.sub_id == 0 and self.change_value == '00':
                 states = [self.state_value[i: i + 1] for i in range(0, len(self.state_value), 1)]
@@ -370,31 +371,28 @@ class SwitchPacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_bool(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.BOOL)
+        return super()._make_scan(ValueType.BOOL)
 
     def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
-        packet.append(int(str(power.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(power.value), 16))
 
 
-class AwayModePacket(ImazuPacket):
-    """Imazu away mode packet
+class AwayPacket(ImazuPacket):
+    """Imazu away packet
     < f7 0e 01 2a 04 40 10 00 19 02 1b 04 82 ee
     < f7 0e 01 2a cmd:04 type:40 sub:10 send:00 data:19021b04 cs:82 ee
     """
 
     class Power(Enum):
-        """AwayMode Power"""
+        """Away Power"""
         ON = "01"
         OFF = "02"
 
     class Valve(Enum):
-        """AwayMode Valve"""
+        """Away Valve"""
         CLOSE = "03"
         OPEN = "04"
 
@@ -404,9 +402,9 @@ class AwayModePacket(ImazuPacket):
             def parse_state(state_value: list[str]):
                 device = Device(state_value[0])
                 if device == Device.LIGHT:
-                    return {'power': AwayModePacket.Power(state_value[1])}
+                    return {'power': AwayPacket.Power(state_value[1])}
                 if device == Device.GAS:
-                    return {'valve': AwayModePacket.Valve(state_value[1])}
+                    return {'valve': AwayPacket.Valve(state_value[1])}
                 _LOGGER.warning('%s unknown state device: %s, %s',
                                 self.name, self.device.name, ''.join(self.packet))
                 return {}
@@ -417,23 +415,17 @@ class AwayModePacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_bool(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.BOOL)
+        return super()._make_scan(ValueType.BOOL)
 
     def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
-        packet.append(int(str(power.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(power.value), 16))
 
     def make_change_valve(self, valve: Valve) -> bytearray:
         """Vavle packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.VALVE)
-        packet.append(int(str(valve.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(valve.value), 16))
 
 
 class FanPacket(ImazuPacket):
@@ -504,23 +496,17 @@ class FanPacket(ImazuPacket):
                         self.name, self.value_type.value, ''.join(self.packet))
         return []
 
-    def make_scan_bool(self) -> bytearray:
+    def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        return self.make_scan(ValueType.BOOL)
+        return super()._make_scan(ValueType.BOOL)
 
     def make_change_power_off(self) -> bytearray:
         """Power off packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
-        packet.append(int(FanPacket.Power.OFF.value, 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.BOOL, int(str(FanPacket.Power.OFF.value), 16))
 
     def make_change_speed(self, speed: Speed) -> bytearray:
         """Speed packet Make"""
-        packet = super().make_base(Cmd.CHANGE, ValueType.DIM)
-        packet.append(int(str(speed.value), 16))
-        packet.append(0)
-        return packet
+        return super().make_change(ValueType.DIM, int(str(speed.value), 16))
 
 
 def parse_packet(packet: str) -> list[ImazuPacket]:
@@ -530,22 +516,22 @@ def parse_packet(packet: str) -> list[ImazuPacket]:
     def _parse_imazu_packet() -> Optional[ImazuPacket]:
         """Imazu packet Parse"""
         device = packets[3]
-        if device == '16':
-            return GuardPacket(packets)
+#        if device == '16':
+#            return GuardPacket(packets)
         if device == '18':
             return ThermostatPacket(packets)
         if device == '19':
             return LightPacket(packets)
-        if device == '1a':
-            return DimmingPacket(packets)
+#        if device == '1a':
+#            return DimmingPacket(packets)
         if device == '1b':
             return GasPacket(packets)
-        if device == '1c':
-            return AcPacket(packets)
+#        if device == '1c':
+#            return AcPacket(packets)
         if device == '1f':
-            return SwitchPacket(packets)
+            return OutletPacket(packets)
         if device == '2a':
-            return AwayModePacket(packets)
+            return AwayPacket(packets)
         if device == '2b':
             return FanPacket(packets)
         _LOGGER.warning('unknown device, %s, %s', device, packets)
